@@ -39,7 +39,8 @@ class APScheduler(object):
         self.allowed_hosts = ['*']
         self.auth = None
         self.api_enabled = False
-        self.api_prefix = ''
+        self.api_prefix = '/scheduler'
+        self.endpoint_prefix = 'scheduler.'
         self.app = None
 
         if app:
@@ -304,6 +305,7 @@ class APScheduler(object):
         self.api_enabled = self.app.config.get('SCHEDULER_VIEWS_ENABLED', self.api_enabled)  # for compatibility reason
         self.api_enabled = self.app.config.get('SCHEDULER_API_ENABLED', self.api_enabled)
         self.api_prefix = self.app.config.get('SCHEDULER_API_PREFIX', self.api_prefix)
+        self.endpoint_prefix = self.app.config.get('SCHEDULER_ENDPOINT_PREFIX', self.endpoint_prefix)
         self.allowed_hosts = self.app.config.get('SCHEDULER_ALLOWED_HOSTS', self.allowed_hosts)
 
     def _load_jobs(self):
@@ -323,15 +325,36 @@ class APScheduler(object):
         """
         Add the routes for the scheduler API.
         """
-        self.app.add_url_rule(self.api_prefix + '/scheduler', 'get_scheduler_info', self._apply_auth(api.get_scheduler_info))
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs', 'add_job', self._apply_auth(api.add_job), methods=['POST'])
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs', 'get_jobs', self._apply_auth(api.get_jobs))
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs/<job_id>', 'get_job', self._apply_auth(api.get_job))
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs/<job_id>', 'delete_job', self._apply_auth(api.delete_job), methods=['DELETE'])
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs/<job_id>', 'update_job', self._apply_auth(api.update_job), methods=['PATCH'])
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs/<job_id>/pause', 'pause_job', self._apply_auth(api.pause_job), methods=['POST'])
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs/<job_id>/resume', 'resume_job', self._apply_auth(api.resume_job), methods=['POST'])
-        self.app.add_url_rule(self.api_prefix + '/scheduler/jobs/<job_id>/run', 'run_job', self._apply_auth(api.run_job), methods=['POST'])
+        self._add_url_route('get_scheduler_info', '', api.get_scheduler_info, 'GET')
+        self._add_url_route('add_job', '/jobs', api.add_job, 'POST')
+        self._add_url_route('get_job', '/jobs/<job_id>', api.get_job, 'GET')
+        self._add_url_route('get_jobs', '/jobs', api.get_jobs, 'GET')
+        self._add_url_route('delete_job', '/jobs/<job_id>', api.delete_job, 'DELETE')
+        self._add_url_route('update_job', '/jobs/<job_id>', api.update_job, 'PATCH')
+        self._add_url_route('pause_job', '/jobs/<job_id>/pause', api.pause_job, 'POST')
+        self._add_url_route('resume_job', '/jobs/<job_id>/resume', api.resume_job, 'POST')
+        self._add_url_route('run_job', '/jobs/<job_id>/run', api.run_job, 'POST')
+
+    def _add_url_route(self, endpoint, rule, view_func, method):
+        """
+        Add a Flask route.
+        :param str endpoint: The endpoint name.
+        :param str rule: The endpoint url.
+        :param view_func: The endpoint func
+        :param str method: The http method.
+        """
+        if self.api_prefix:
+            rule = self.api_prefix + rule
+
+        if self.endpoint_prefix:
+            endpoint = self.endpoint_prefix + endpoint
+
+        self.app.add_url_rule(
+            rule,
+            endpoint,
+            self._apply_auth(view_func),
+            methods=[method]
+        )
 
     def _apply_auth(self, view_func):
         """
